==> bfilter_1.0.6.orig.tar.gz: bfilter-1.0.6/main/CraftedResponse.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef CRAFTEDRESPONSE_H_
#define CRAFTEDRESPONSE_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "SplittableBuffer.h"
#include "HttpResponseMetadata.h"
#include <memory>

class CraftedResponse
{
public:
	CraftedResponse(int status_code);
	
	~CraftedResponse();
	
	// Default copy constructor and assignment operator OK
	
	HttpResponseMetadata& metadata() { return *m_ptrMetadata; }
	
	HttpResponseMetadata const& metadata() const { return *m_ptrMetadata; }
	
	std::auto_ptr<HttpResponseMetadata> retrieveMetadata() { return m_ptrMetadata; }
	
	SplittableBuffer& body() { return m_body; }
	
	SplittableBuffer const& body() const { return m_body; }
private:
	std::auto_ptr<HttpResponseMetadata> m_ptrMetadata;
	SplittableBuffer m_body;
};

#endif

==> bfilter_1.1.4.orig.tar.gz: bfilter-1.1.4/main/CraftedResponse.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef CRAFTEDRESPONSE_H_
#define CRAFTEDRESPONSE_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "NonCopyable.h"
#include "ImmediateResponse.h"
#include "SplittableBuffer.h"
#include "HttpResponseMetadata.h"
#include "RequestPtr.h"
#include <memory>

class CraftedResponse : public ImmediateResponse
{
	DECLARE_NON_COPYABLE(CraftedResponse)
public:
	CraftedResponse(int status_code);
	
	virtual ~CraftedResponse();
	
	virtual void output(
		AbstractResponseHandler& handler,
		ConstRequestPtr const& request,
		RequestStatus& request_status,
		RequestTag const& request_tag);
	
	HttpResponseMetadata& metadata() { return *m_ptrMetadata; }
	
	HttpResponseMetadata const& metadata() const { return *m_ptrMetadata; }
	
	std::auto_ptr<HttpResponseMetadata> retrieveMetadata() { return m_ptrMetadata; }
	
	SplittableBuffer& body() { return m_body; }
	
	SplittableBuffer const& body() const { return m_body; }
private:
	std::auto_ptr<HttpResponseMetadata> m_ptrMetadata;
	SplittableBuffer m_body;
};

#endif
